Keep-alive vs Disconnect — Vaurien 0.4 documentation

### Navigation

- index
- next |
- previous |
- Vaurien 0.4 documentation »

# Keep-alive vs Disconnect

Explain here the different strategies

#### Previous topic

Writing Handlers

#### Next topic

Examples

### This Page

- Show Source

### Quick search

Enter search terms or a module, class or function name.

### Navigation

- index
- next |
- previous |
- Vaurien 0.4 documentation »

© Copyright 2012, Mozilla. Created using Sphinx 1.1.3.